      REAL FUNCTION FLTRN()
C
C**** PURPOSE: RETURNS A SINGLE PRECISION FLOATING POINT RANDOM
C****          NUMBER IN THE OPEN INTERVAL (0,1).
C****          WORKS ON ANY SYSTEM FOR WHICH THE MAXIMUM VALUE
C****          OF AN INTEGER VARIABLE IS 2**31-1 OR LARGER.
C
C**** ARGUMENTS:  (NONE)
C****             SEED NUMBER IS KEPT IN COMMON
C
C**** SUBPROGRAMS CALLED:
C**** MOD    - FORTRAN INTRINSIC FUNCTION TO RETURN REMAINDER
C**** REAL   - FORTRAN INTRINSIC FUNCTION TO CONVERT TO SINGLE PRECISION
C
C**** METHOD:  MINIMAL STANDARD GENERATOR SPECIFIED IN THE ARTICLE
C****          S. K. PARK AND K. W. MILLER, "RANDOM NUMBER GENERATORS:
C****          GOOD ONES ARE HARD TO FIND", COMM. ACM, VOL. 31, NO. 10,
C****          OCTOBER 1988.
C
C**** AUTHOR:  J. C. RYMAN
C****          NUCLEAR ENGINEERING APPLICATIONS
C****          COMPUTING & TELECOMMUNICATIONS DIVISION
C****          OAK RIDGE NATIONAL LABORATORY
C****          P. O. BOX 2008
C****          OAK RIDGE, TN  37831
C
      INTEGER SEED
C**** COMMON/RANCOM/ DATA FOR RANDOM NUMBER PACKAGE
      COMMON/RANCOM/ SEED
C**** SEED   = SEED FOR NEXT CALL TO FUNCTION RANDOM
C
      INTEGER A,M,Q,R,LO,HI,TEST
      REAL MINV
      PARAMETER(A=16807,M=2147483647,Q=127773,R=2836)
      PARAMETER(MINV=4.6566129E-10)
C
C**** Q    = M/A
C**** R    = MOD(M,A)
C**** MINV = 1/M
C
C
      HI=SEED/Q
      LO=MOD(SEED,Q)
      TEST=A*LO-R*HI
C
      IF(TEST.GT.0) THEN
         SEED=TEST
      ELSE
         SEED=TEST+M
      ENDIF
C
      FLTRN = MINV*REAL(SEED)
      RETURN
      END
